/*
 * FileWrapper.java
 */

/*
 * This class provide R/W access to the specified file.
 */

package antext.util;

import java.io.File;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.FileInputStream;

import java.io.BufferedWriter;
import java.io.OutputStreamWriter;
import java.io.FileOutputStream;

import java.io.IOException;

import antext.util.Constants;

import org.apache.tools.ant.BuildException;

/**
 *
 * @author  pknakal
 * @version 3.0
 */
public class FileWrapper extends Object {
    private File file = null; //a file for I/O operations
    private BufferedReader reader = null; //a file reader
    private BufferedWriter writer = null; //a file writer

    public static FileWrapper getWrapper(String fileName) {
        return new FileWrapper(new File(fileName) );
    }

    private FileWrapper(File file) {
        this.file = file;

        if (file.isDirectory() ) {
            throw new BuildException("[FileWrapper] " + Constants.fw_not_file + " : " + file.getAbsolutePath() ); //NOI18N
        } else {
            if (!(file.exists() ? (file.canWrite() && file.canRead()) : true) ) {
                throw new BuildException("[FileWrapper] " + Constants.fw_not_RW + " : " + file.getAbsolutePath() ); //NOI18N
            }
        }
    }

    public boolean exists() {
        return file.exists();
    }

    public boolean write(String data) {
        try {
            if (this.reader != null) {
                this.reader.close();
                this.reader = null;
            }
            if (this.writer == null) {
                this.writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(this.file), Constants.encoding) );
            }
            this.writer.write(data);
            this.writer.flush();
        } catch (IOException exc) {
            return false;
        }
        return true;
    }

    public String read() {
        try {
            if (this.writer != null) {
                this.writer.close();
                this.writer = null;
            }
            if (this.reader == null) {
                this.reader = new BufferedReader(new InputStreamReader(new FileInputStream(this.file), Constants.encoding) );
            }
            return this.reader.readLine();
        } catch (IOException exc) {
            return null;
        }
    }

    public boolean close() {
        try {
            if (this.writer != null) {
                this.writer.close();
                this.writer = null;
            }
            if (this.reader != null) {
                this.reader.close();
                this.reader = null;
            }
            return true;
        } catch (IOException exc) {
            return false;
        }
    }

}
