/* @(#)SignatureTest.java	1.11 04/16/98 Jonathan Gibbons, Kevin A. Smith
 *
 * Copyright (c) 1996-1998 Sun Microsystems, Inc.  All Rights Reserved.
 * This software is the confidential and proprietary information of Sun 
 * Microsystems, Inc. ("Confidential Information"). You shall not 
 * disclose such Confidential Information and shall use it only in 
 * accordance with the terms of the license agreement you entered into 
 * with Sun. 
 * 
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF 
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR 
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR 
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. 
 *
 * This test must be run before running the rest of the api tests.
 */

package javasoft.sqe.jck.extension.lib;

import java.io.DataInputStream;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.PrintStream;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.net.URL;
import java.net.MalformedURLException;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Hashtable;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;

import javasoft.sqe.harness.Status;
import javasoft.sqe.harness.Test;

/**
 * Usage: -TestURL - location of test description
 *      : -FileName - name of signatures file
 *      : -setup - whether to run in setup mode
 *      : -PackageName - The name of the package to search for.
 */

public class SignatureTest 
implements javasoft.sqe.harness.Test
{
    public static void main(String[] args) {
	SignatureTest t = new SignatureTest();
	Status s = t.run(args, System.err, System.out);
	s.exit();
    }

    public Status run(String[] args, PrintStream log, PrintStream ref) {
	this.log = log;
	// ref ignored
	boolean setup = false;
	String testURL = null;
	String fileName = null;
	URL sigFile;

	for( int i = 0; i < args.length; ++i ) {
	    if( args[i].equals( "-setup" ) ) {
		setup = true;
	    }
	    else if( args[i].equals( "-TestURL" ) &&
		     args.length > i + 1 ) {
		testURL = args[++i];
	    }
	    else if( args[i].equals( "-FileName") &&
		     args.length > i + 1 ) {
		fileName = args[++i];
	    }
	    else if( args[i].equals("-PackageName") &&
		     args.length > i + 1 ) {
		packageName = args[++i];
	    }
	}
			
	// check arguments
	if( testURL == null || fileName == null ) {
	    return Status.failed( "Invalid arguments" );
	}

	// Construct package name
	if(! packageName.equals( "java" )) {
	    packageName = packageName.replace('.', File.separatorChar);
	}

	// Construct file name
	try {
	    sigFile = new URL( testURL );
	    sigFile = new URL( sigFile, fileName );
	}
	catch( MalformedURLException e) {
	    return Status.notApplicable( "Invalid URL" );
	}
	// run test
	if( setup == true ) {
	    return setup( sigFile.getFile() );
	}
	else {
	    return verify( sigFile );
	}

    }
    
    private Status setup(String outFileName) {
	try {
	    PrintStream out = new PrintStream(new FileOutputStream(outFileName));
	    String path = System.getProperty("java.class.path");
	    while (path != null && path.length() > 0) {
		String s;
		int index = path.indexOf(File.pathSeparatorChar);
		if (index == -1) {
		    s = path;
		    path = null;
		} else {
		    s = path.substring(0, index);
		    path = path.substring(index + 1);
		}
		// remove trailing separator, if necessary
		if (s.endsWith(File.separator))
		    s = s.substring(0, s.length() - File.separator.length());
		File pathEntry = new File(s);
		if (pathEntry.isDirectory()) {
		    File javaPathEntry = new File(pathEntry, packageName);
		    if (javaPathEntry.exists() && javaPathEntry.isDirectory()) {
			scanDir(out, javaPathEntry, packageName);
		    }
		} else {
		    // assume it is a zip file
		    scanZip(out, pathEntry);
		}
	    }
	    out.close();
	}
	catch (IOException e) {
	    log.println("problem creating definitions file");
	    log.println(e);
	    return Status.failed("problem creating definitions file");
	}

	if (errors == 0)
	    return Status.passed("");
	else 
	    return Status.failed(errors + " errors");	
    }

    private void scanClass(PrintStream out, String name) {
	String tempString;

	// BIG HUGE HACK
	/* Because development has put non-public public
	 * classes in the java.* name space
	 * we must not include them in the list of required
	 * classes.
	 */
	String forbiddenClasses[] = {
	    "java.lang.UNIXProcess",
	    "java.lang.Win32Process",
	    "java.text.resources",
	};

	for( int j = 0; j < forbiddenClasses.length; ++j ) {
	    if( name.startsWith( forbiddenClasses[j] ) ) {
		log.println( "Ignoring " + name );
		return;
	    }
	}
		
	try {
	    Class c = Class.forName(name);
	    if (!Modifier.isPublic(c.getModifiers())) {
		log.println("Ignoring " + name);
		return;
	    }

	    out.println(CLASS + name);
	    Class spr = c.getSuperclass();
	    out.println(SUPER + spr);
	    Class[] intfs = c.getInterfaces();
	    for (int i = 0; i < intfs.length; i++)
		out.println(INTERFACE + intfs[i]);
	    Constructor[] constrs = c.getConstructors();
	    for (int i = 0; i < constrs.length; i++) {
		out.println( CONSTRUCTOR + getMemberName( constrs[i] ) );
	    }
	    Method[] methods = c.getMethods();
	    for (int i = 0; i < methods.length; i++) {
		out.println( METHOD + getMemberName( methods[i] ) );
	    }
	    Field[] fields = c.getFields();
	    for (int i = 0; i < fields.length; i++) {
		out.println( FIELD + fields[i] ); 
	    }
	}
	catch (ClassNotFoundException ex) {
	    problem("Class not found: " + name);
	}
    }

    private void scanDir(PrintStream out, File dir, String pkg) {
	String[] files = dir.list();
	for (int i = 0; i < files.length; i++) {
	    File f = new File(dir, files[i]);
	    if (files[i].endsWith(".class"))
		scanClass(out, pkg + "." + files[i].substring(0, files[i].length() - 6));
	    else if (f.isDirectory()) 
		scanDir(out, f, pkg + "." + files[i]);
	}
    }

    private void scanZip(PrintStream out, File zipfile) {
	try {
	    ZipFile z = new ZipFile(zipfile);
	    for (Enumeration e = z.entries(); e.hasMoreElements(); ) {
		ZipEntry ze = (ZipEntry)e.nextElement();
		String name = ze.getName();
		// added separator character test
		if( '/' != File.separatorChar ) 
		    packageName = packageName.replace( File.separatorChar, '/' );
		if (name.startsWith(packageName + "/") && name.endsWith(".class")) 
		    scanClass(out, name.substring(0, name.length()-6).replace('/', '.'));
	    }
	}
	catch (IOException e) {
	    log.println("Ignoring " + zipfile + ": " + e);
	}
    }

    private Status verify( URL sigFileURL ) {
	classes = new Hashtable();
	// first, scan the file for classes constructors/methods/fields that are required
	try {
	    DataInputStream in = new DataInputStream( sigFileURL.openStream( ) );
	    String line;
	    while ((line = in.readLine()) != null) {
		if (line.startsWith(CLASS))
		    setCurrentClass(line.substring(CLASS.length()));
		else 
		    require(line);
	    }
	    in.close();
	}
	catch (IOException e) {
	    log.println("problem with definitions file");
	    log.println(e);
	    return Status.failed("problem with definitions file");
	}

	// now, for each class that was found, check the constructors/methods/fields
	// found by this implementation
	for (Enumeration e = classes.keys(); e.hasMoreElements(); ) {
	    String name = (String)e.nextElement();
	    currentClass = (Hashtable)classes.get(name);
	    try {
		Class c = Class.forName(name);
		Class spr = c.getSuperclass();
		found(SUPER + spr);
		Class[] intfs = c.getInterfaces();
		for (int i = 0; i < intfs.length; i++)
		    found(INTERFACE + intfs[i]);
		Constructor[] constrs = c.getConstructors();
		for (int i = 0; i < constrs.length; i++)
		    found(CONSTRUCTOR + getMemberName( constrs[i] ) );
		Method[] methods = c.getMethods();
		for (int i = 0; i < methods.length; i++)
		    found(METHOD + getMemberName( methods[i] ) );
		Field[] fields = c.getFields();
		for (int i = 0; i < fields.length; i++)
		    found(FIELD + fields[i]);
	    }
	    catch (ClassNotFoundException ex) {
		problem("Required class not found in implementation: " + name);
	    }
	}

	for (Enumeration e1 = classes.keys(); e1.hasMoreElements(); ) {
	    String name = (String)e1.nextElement();
	    Hashtable c = (Hashtable)classes.get(name);
	    for (Enumeration e2 = c.elements(); e2.hasMoreElements(); ) {
		SigInfo si = (SigInfo)e2.nextElement();
		if (si.required && !si.found) 
		    problem("Definition required but not found in " + name + "\n    " + si);
		else if  (si.found && !si.required) 
		    problem("Definition found but not permitted in " + name + "\n    " + si);
	    }
	}
		
	 
	if (errors == 0)
	    return Status.passed("");
	else 
	    return Status.failed(errors + " errors");	
    }

    private void setCurrentClass(String name) {
	Hashtable h = (Hashtable)classes.get(name);
	if (h == null) {
	    h = new Hashtable();
	    classes.put(name, h);
	}
	currentClass = h;
    }

    private void found(String label) {
	SigInfo e = (SigInfo)currentClass.get(label);
	if (e == null) {
	    e = new SigInfo(label);
	    currentClass.put(label, e);
	}
	e.found = true;
    }

    private void require(String label) {
	SigInfo e = (SigInfo)currentClass.get(label);
	if (e == null) {
	    e = new SigInfo(label);
	    currentClass.put(label, e);
	}
	e.required = true;
    }

    private void problem(String msg) {
	log.println(msg);
	errors++;
    }

    // Strip native and synchronized from entry value
    private String getMemberName( Constructor ctor ) {
	Class args[];
	Class exceptions[];
	int i;
	int startIndex = 0;
	String modifiers = Modifier.toString( ctor.getModifiers() );
	StringBuffer retVal = new StringBuffer("");

	args = ctor.getParameterTypes();
	exceptions = ctor.getExceptionTypes();

	// strip implementation modifiers
	// SYNCHRONIZED should always be second to last.
	startIndex = modifiers.indexOf( SYNCHRONIZED );
	if( startIndex == 0 ) {
	    modifiers = "";
	}
	else if( startIndex > 0 ) {
	    modifiers = modifiers.substring( 0, startIndex - 1 ); 
	}

	// NATIVE should always be the last modifier on the list.
	startIndex = modifiers.indexOf( NATIVE );
	if( startIndex == 0 ) {
	    modifiers = "";
	}
	else if( startIndex > 0 ) {
	    modifiers = modifiers.substring( 0, startIndex - 1 );
	}
			
	// Construct the string
	retVal.append( modifiers + " " + ctor.getName() + "(" );
	if( args.length > 0 ) {
	    retVal.append( args[0].getName() );
	}
	for( i = 1; i < args.length; ++i ) {
	    retVal.append( "," + args[i].getName() );
	}
	retVal.append( ")" );
		
	// Get throwables, put them in alphabetic order
	if( exceptions.length > 0 ) {
	    retVal.append(" throws ");
	    retVal.append( getExceptionNames( exceptions ) );
	}
	
	return retVal.toString();
    }


    // Strip native and synchronized from entry value
    private String getMemberName( Method meth ) {
	Class args[];
	Class exceptions[];
	Class returnType;
	int i;
	int startIndex = 0;
	String modifiers = Modifier.toString( meth.getModifiers() );
	StringBuffer retVal = new StringBuffer("");

	returnType = meth.getReturnType();
	args = meth.getParameterTypes();
	exceptions = meth.getExceptionTypes();

	// strip implementation modifiers
	// SYNCHRONIZED should always be second to last
	startIndex = modifiers.indexOf( SYNCHRONIZED );
	if( startIndex == 0 ) {
	    modifiers = "";
	}
	else if( startIndex > 0 ) {
	    modifiers = modifiers.substring( 0, startIndex - 1 );
	}

	// NATIVE should always be the last modifier on the list.
	startIndex = modifiers.indexOf( NATIVE );
	if( startIndex == 0 ) {
	    modifiers = "";
	}
	else if( startIndex > 0 ) {
	    modifiers = modifiers.substring( 0, startIndex - 1 );
	}

	// Construct the string
	retVal.append( modifiers + " " + 
		       returnType.getName() + " " +
		       meth.getName() + "(" );
	if( args.length > 0 ) {
	    retVal.append( args[0].getName() );
	}
	for( i = 1; i < args.length; ++i ) {
	    retVal.append( "," + args[i].getName() );
	}
	retVal.append( ")" );
		
	// Get throwables, put them in alphabetic order
	if( exceptions.length > 0 ) {
	    retVal.append(" throws ");
	    retVal.append( getExceptionNames( exceptions ) );
	}

	return retVal.toString();
    }

    /** Create a string of all of the exception type names
     * put the string of names in alphabetic order because 
     * ordering of throws clauses is not a binary compatibility
     * requirement.
     */
    private String getExceptionNames( Class exceptions[] ) {
	int i;
	int j;
	int min;
	String temp;
	String exceptionNames[] = new String[ exceptions.length ];
	StringBuffer retVals = new StringBuffer();

	// Get exception classes names
	for(i = 0; i < exceptions.length; ++i) {
	    exceptionNames[i] = exceptions[i].getName();
	}

	// simple selection sort of the array of exceptionNames
	for(i = 0; i < exceptionNames.length; ++i) {
	    min = i;
	    for( j = i + 1; j < exceptionNames.length; ++j ) {
		if( exceptionNames[j].compareTo(exceptionNames[min]) < 0 )
		    min = j;
	    }
	    temp = exceptionNames[min];
	    exceptionNames[min] = exceptionNames[i];
	    exceptionNames[i] = temp;
	}

	/* Convert the items in the vector to a StringBuffer 
	 * return the stringVal of the buffer to calling method
	 */
	for( i = 0; i < exceptionNames.length - 1; ++i ) {
	    retVals.append( exceptionNames[i] + ", " );
	}
	retVals.append( exceptionNames[ exceptionNames.length - 1 ] );
	return retVals.toString();
    }

    Hashtable classes;      // Hashtable<className, Hashtable<methodFieldConstrName, info>>
    Hashtable currentClass; // Hashtable<methodFieldConstrName, info>
    PrintStream log;
    int errors;
    String packageName = "java";

    static final String 
        CLASS        = "CLSS ",
        SUPER        = "supr ",
        INTERFACE    = "intf ",
        CONSTRUCTOR  = "cons ",
        METHOD       = "meth ",
        FIELD        = "fld  ",
	NATIVE       = "native",
	SYNCHRONIZED = "synchronized";
}

class SigInfo
{
    SigInfo(String label) { this.label = label; }
    public String toString() {
	for (int i = 0; i < prefixes.length; i++) {
	    if (label.startsWith(prefixes[i][0])) 
		return (prefixes[i][1] + label.substring(prefixes[i][0].length()));
	}
	return label;
    }

    String label;
    boolean required;
    boolean found;

    private static final String[][] prefixes = {
	{SignatureTest.CLASS, "class "},
	{SignatureTest.SUPER, "superclass "},
	{SignatureTest.INTERFACE, "interface "},
	{SignatureTest.CONSTRUCTOR, "constructor "},
	{SignatureTest.METHOD, "method "},
	{SignatureTest.FIELD, "field "}
    };
}
