/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... JHelpTOCNavigator(hs).expandID(target) --> JHelpTOCNavigator(hs).expandID(target)
 */

package javasoft.sqe.tests.api.javax.help.JHelpTOCNavigator;

import java.io.PrintWriter;

import java.awt.Panel;
import java.awt.Container;
import java.awt.FlowLayout;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.applet.Applet;

import java.net.URL;

import java.util.Locale;
import java.util.Hashtable;

import javax.swing.JFrame;
import javax.swing.JButton;

import javax.help.JHelp;
import javax.help.HelpSet;
import javax.help.HelpModel;
import javax.help.NavigatorView;
import javax.help.DefaultHelpModel;
import javax.help.JHelpTOCNavigator;

import javasoft.sqe.javatest.Status;
import javasoft.sqe.javatest.lib.InteractiveTest;

/**
 * Tests for javax.help.JHelpTOCNavigator ... expandID(...)
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class ExpandIDTest extends InteractiveTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public ExpandIDTest() {
        super("YesNo");
    }

    public static void main(String argv[]) {
        ExpandIDTest test = new ExpandIDTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }

    protected Status init(String[] args) {
        testCases = new String[1];
        testCases[0] = "expandIDtest";
        return Status.passed("");
    }


    /**
     * Method test: <code>void expandID(java.lang.String target)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>target</code> valid value
     */
    public void expandIDtest() {
        addInfo("This test checks expandID(java.lang.String target) method.");
        addInfo("1) A Frame with TOC should be displayed ... all nodes should be collapsed");
        addInfo("2) A Frame with 'ExpandID' button should be displayed");
        addInfo("3) Click the 'ExpandID' button and the 'Hostory of Easter' should be expanded");
        addInfo("4) Click 'Yes', if the functionality is OK otherwise click 'No' button");
        ExpandIDTestClass testPanel = new ExpandIDTestClass();
        addTestPanel((java.awt.Panel)testPanel);

        setStatusMessages("OK", "Did not work");
        setFrameTitle("JHelpTOCNavigator.expandID(target)");
        setTimeout(600);
    }


    /**
     * Help class with JHelpTOCNavigator construction and JFrame for expandID button
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    class ExpandIDTestClass extends Applet implements ActionListener {
        private JButton expandIDButton = null;
        private JHelpTOCNavigator jhTOCNavigator = null;

        public ExpandIDTestClass() {
            try {
                //create a HelpSet object ... start
                HelpSet hs = new HelpSet(this.getClass().getClassLoader(), new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs") );
                //create a HelpSet object ... end

                //create a HelpModel object ... start
                HelpModel helpmodel = new DefaultHelpModel(hs);
                //create a HelpModel object ... end

                //get a JHelpTOCNavigator ... start
                jhTOCNavigator = (JHelpTOCNavigator)hs.getNavigatorView("TOC").createNavigator(helpmodel);
                //get a JHelpTOCNavigator ... end

                //create JFrame with previously created JHelpTOCNavigator and show it ... start
                JFrame frame = new JFrame("JHelpTOCNavigator.expandID(target)");
                frame.getContentPane().add(jhTOCNavigator);
                frame.setResizable(true);
                frame.pack();
                frame.setSize(220, 400);
                frame.show();
                //create JFrame with previously created JHelpTOCNavigator and show it ... end

                //create a expandIDButton and setup action listener for it ... start
                expandIDButton = new JButton("ExpandID");
                expandIDButton.addActionListener(this);
                //create a expandIDButton and setup action listener for it ... end

                //setup JFrame with expandIDButton and show it ... start
                JFrame expandIDFrame        = new JFrame("ExpandID Frame");
                Container expandIDContainer = expandIDFrame.getContentPane();
                expandIDContainer.setLayout(new FlowLayout() );
                expandIDContainer.add(expandIDButton);
                expandIDFrame.setResizable(false);
                expandIDFrame.pack();
                expandIDFrame.show();
                //setup JFrame with expandIDButton and show it ... end
            } catch (Exception exc) {
                exc.printStackTrace();
                return;
            }
        }


        public void actionPerformed(ActionEvent event) {
            if(event.getSource() == expandIDButton) {
                //expandID the JHelpTOCNavigator ... start
                jhTOCNavigator.expandID("easter_history");
                //expandID the JHelpTOCNavigator ... end
            }
        }
    }

}
