/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... AccessibleJHelpNavigator(...).getAccessibleRole() --> JHelpNavigator(...).getAccessibleContext().getAcdcessibleRole()
 */

package javasoft.sqe.tests.api.javax.help.AccessibleJHelpNavigator;

import java.io.PrintWriter;

import java.net.URL;

import java.util.Locale;
import java.util.Hashtable;

import javax.help.HelpSet;
import javax.help.NavigatorView;
import javax.help.JHelpNavigator;
import javax.help.DefaultHelpModel;

import javax.swing.UIManager;
import javax.swing.UIDefaults;

import javax.accessibility.AccessibleRole;
import javax.accessibility.AccessibleContext;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.JHelpNavigator.AccessibleJHelpNavigator ... getAccessibleRole()
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class GetAccessibleRoleTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public GetAccessibleRoleTest() {
    }

    public static void main(String argv[]) {
        GetAccessibleRoleTest test = new GetAccessibleRoleTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Method test: <code>javax.accessibility.AccessibleRole getAccessibleRole()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase1() {
        String apiTested = "javax.accessibility.AccessibleRole getAccessibleRole(): "
            + "TestCase: '(new JHelpNavigator(...)).getAccessibleContext().getAccessibleRole()' "
            + "ExpectedResult: Return 'AccessibleRole.PANEL' "
            + "ObtainedResult: ";

        try {
            //create JHelpNavigator object ... start
            HelpSet hs = new HelpSet(this.getClass().getClassLoader(), new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs") );
            Hashtable hashtable = new Hashtable();
            hashtable.put("data", "HolidayTOC.xml");
            NavigatorView navview = NavigatorView.create(hs, "myview", "mylabel", Locale.getDefault(), "javax.help.TOCView", hashtable);
            UIDefaults table = UIManager.getLookAndFeelDefaults();
            Object[] uiDefaults = {"HelpNavigatorUI", "com.sun.help.jck.harness.TestNavigatorUI"};
            table.putDefaults(uiDefaults);
            JHelpNavigator jhnavigator = new JHelpNavigator(navview, new DefaultHelpModel(navview.getHelpSet()));
            //create JHelpNavigator object ... end


            if(jhnavigator.getAccessibleContext().getAccessibleRole().equals(AccessibleRole.PANEL) ) {
                return Status.passed(apiTested + "Returned 'AccessibleRole.PANEL'");
            } else {
                return Status.failed(apiTested + "Did not return 'AccessibleRole.PANEL'");
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
