/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... DefaultHelpBroker().getSize() --> DefaultHelpBroker().getSize()
 * testCase2 ... DefaultHelpBroker(hs).getSize() --> DefaultHelpBroker(hs).getSize()
 * testCase3 ... DefaultHelpBroker(hs).setSize(d).getSize() --> DefaultHelpBroker(hs).setSize(d[10,10]).getSize()
 * testCase4 ... DefaultHelpBroker(hs).setSize(d).getSize() --> DefaultHelpBroker(hs).setSize(d[0,0]).getSize()
 * testCase5 ... DefaultHelpBroker(hs).setSize(d).getSize() --> DefaultHelpBroker(hs).setSize(d[-10,-10]).getSize()
 */

package javasoft.sqe.tests.api.javax.help.DefaultHelpBroker;

import java.io.PrintWriter;

import java.net.URL;

import java.awt.Dimension;
import java.awt.IllegalComponentStateException;

import javax.help.HelpSet;
import javax.help.DefaultHelpBroker;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.DefaultHelpBroker ... getSize()
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class GetSizeTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public GetSizeTest() {
    }

    public static void main(String argv[]) {
        GetSizeTest test = new GetSizeTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Method test: <code>java.awt.Dimension getSize()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase1() {
        String apiTested = "java.awt.Dimension getSize(): "
            + "TestCase: '(new DefaultHelpBroker()).getSize()' "
            + "ExpectedResult: Dimension of 645,495 "
            + "ObtainedResult: ";

        try {
            //create DefaultHelpBroker object ... start
            DefaultHelpBroker defaultHelpBroker = new DefaultHelpBroker();
            //create DefaultHelpBroker object ... end

	    Dimension testd = new Dimension(645,495);
            Dimension d = defaultHelpBroker.getSize();

	    if (testd.equals(d)) {
		return Status.passed(apiTested + "Got Deminsion of 645,495");
	    } else {
		return Status.failed(apiTested + "Got Deminsion=" + d);
	    }
        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>java.awt.Dimension getSize()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase2() {
        String apiTested = "java.awt.Dimension getSize(): "
            + "TestCase: '(new DefaultHelpBroker(hs)).getSize()' "
            + "ExpectedResult: 'java.awt.IllegalComponentStateException' "
            + "ObtainedResult: ";

        try {
            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsurl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsurl);
            //creating HelpSet object ... end

            //create DefaultHelpBroker object ... start
            DefaultHelpBroker defaultHelpBroker = new DefaultHelpBroker(hs);
            //create DefaultHelpBroker object ... end

	    Dimension testd = new Dimension(645,495);
            Dimension d = defaultHelpBroker.getSize();

	    if (testd.equals(d)) {
		return Status.passed(apiTested + "Got Deminsion of 645,495");
	    } else {
		return Status.failed(apiTested + "Got Deminsion=" + d);
	    }
        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>java.awt.Dimension getSize()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase3() {
        String apiTested = "java.awt.Dimension getSize(): "
            + "TestCase: '(new DefaultHelpBroker(hs)).setSize(d[10,10]).getSize()' "
            + "ExpectedResult: 'd' "
            + "ObtainedResult: ";

        try {
            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsurl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsurl);
            //creating HelpSet object ... end

            //create DefaultHelpBroker object ... start
            DefaultHelpBroker defaultHelpBroker = new DefaultHelpBroker(hs);
            //create DefaultHelpBroker object ... end

            //set size ... start
            Dimension d = new Dimension(10, 10);
            defaultHelpBroker.setSize(d);
            //set size ... end

            if(d.equals(defaultHelpBroker.getSize()) ) {
                return Status.passed(apiTested + "Got 'd'");
            } else {
                return Status.failed(apiTested + "Did not get 'd': " + defaultHelpBroker.getSize() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>java.awt.Dimension getSize()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase4() {
        String apiTested = "java.awt.Dimension getSize(): "
            + "TestCase: '(new DefaultHelpBroker(hs)).setSize(d[0,0]).getSize()' "
            + "ExpectedResult: 'd' "
            + "ObtainedResult: ";

        try {
            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsurl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsurl);
            //creating HelpSet object ... end

            //create DefaultHelpBroker object ... start
            DefaultHelpBroker defaultHelpBroker = new DefaultHelpBroker(hs);
            //create DefaultHelpBroker object ... end

            //set size ... start
            Dimension d = new Dimension(0, 0);
            defaultHelpBroker.setSize(d);
            //set size ... end

            if(d.equals(defaultHelpBroker.getSize()) ) {
                return Status.passed(apiTested + "Got 'd'");
            } else {
                return Status.failed(apiTested + "Did not get 'd': " + defaultHelpBroker.getSize() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>java.awt.Dimension getSize()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase5() {
        String apiTested = "java.awt.Dimension getSize(): "
            + "TestCase: '(new DefaultHelpBroker(hs)).setSize(d[-10,-10]).getSize()' "
            + "ExpectedResult: 'd' "
            + "ObtainedResult: ";

        try {
            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsurl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsurl);
            //creating HelpSet object ... end

            //create DefaultHelpBroker object ... start
            DefaultHelpBroker defaultHelpBroker = new DefaultHelpBroker(hs);
            //create DefaultHelpBroker object ... end

            //set size ... start
            Dimension d = new Dimension(-10, -10);
            defaultHelpBroker.setSize(d);
            //set size ... end

            if(d.equals(defaultHelpBroker.getSize()) ) {
                return Status.passed(apiTested + "Got 'd'");
            } else {
                return Status.failed(apiTested + "Did not get 'd': " + defaultHelpBroker.getSize() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
