/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... FavoritesItem().emptyInitState() --> FavoritesItem().emptyInitState()
 *
 * testCase2 ... FavoritesItem(name).emptyInitState() --> FavoritesItem(name).emptyInitState()
 * testCase3 ... FavoritesItem(name).emptyInitState() --> FavoritesItem(null).emptyInitState()
 *
 * testCase4 ... FavoritesItem(name, target, url, title, locale).emptyInitState() --> FavoritesItem(name, target, url, title, locale).emptyInitState()
 * testCase5 ... FavoritesItem(name, target, url, title, locale).emptyInitState() --> FavoritesItem(null, null, null, null, null).emptyInitState()
 * testCase6 ... FavoritesItem(name, target, url, title, locale).emptyInitState() --> FavoritesItem("", "", "", "", locale).emptyInitState()
 */

package javasoft.sqe.tests.api.javax.help.FavoritesItem;

import java.io.PrintWriter;

import java.net.URL;

import java.util.Locale;

import javax.help.HelpSet;
import javax.help.FavoritesItem;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.FavoritesItem ... emptyInitState()
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class EmptyInitStateTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public EmptyInitStateTest() {
    }

    public static void main(String argv[]) {
        EmptyInitStateTest test = new EmptyInitStateTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Method test: <code>boolean emptyInitState()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase1() {
        String apiTested = "boolean emptyInitState(): "
            + "TestCase: '(new FavoritesItem()).emptyInitState()' "
            + "ExpectedResult: 'true' "
            + "ObtainedResult: ";

        try {
            //construc a object ... start
            FavoritesItem fItem = new FavoritesItem();
            //construc a object ... end


            if(fItem.emptyInitState() ) {
                return Status.passed(apiTested + "Got 'true'");
            } else {
                return Status.failed(apiTested + "Did not get 'true': " + fItem.emptyInitState() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>boolean emptyInitState()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase2() {
        String apiTested = "boolean emptyInitState(): "
            + "TestCase: '(new FavoriteItem(name)).emptyInitState()' "
            + "ExpectedResult: 'true' "
            + "ObtainedResult: ";

        try {
            //construc a object ... start
            String name = "favorites item";
            FavoritesItem fItem = new FavoritesItem(name);
            //construc a object ... end


            if(fItem.emptyInitState() ) {
                return Status.passed(apiTested + "Got 'true'");
            } else {
                return Status.failed(apiTested + "Did not get 'true': " + fItem.emptyInitState() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>boolean emptyInitState()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase3() {
        String apiTested = "boolean emptyInitState(): "
            + "TestCase: '(new FavoriteItem(null)).emptyInitState()' "
            + "ExpectedResult: 'true' "
            + "ObtainedResult: ";

        try {
            //construc a object ... start
            String name = null;
            FavoritesItem fItem = new FavoritesItem(name);
            //construc a object ... end


            if(fItem.emptyInitState() ) {
                return Status.passed(apiTested + "Got 'true'");
            } else {
                return Status.failed(apiTested + "Did not get 'true': " + fItem.emptyInitState() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>boolean emptyInitState()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase4() {
        String apiTested = "boolean emptyInitState(): "
            + "TestCase: '(new FavoritesItem(name, target, url, title, locale)).emptyInitState()' "
            + "ExpectedResult: 'true' "
            + "ObtainedResult: ";

        try {
            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsurl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsurl);
            //creating HelpSet object ... end

            //setting necessary String objects ... start
            String name = "favorites item";
            String target = "view";
            String url = hs.getHelpSetURL().toExternalForm();
            String title = hs.getTitle();
            Locale locale = Locale.getDefault();
            //setting necessary String objects ... end

            //construc a object ... start
            FavoritesItem fItem = new FavoritesItem(name, target, url, title, locale);
            //construc a object ... end


            if(fItem.emptyInitState() ) {
                return Status.passed(apiTested + "Got 'true'");
            } else {
                return Status.failed(apiTested + "Did not get 'true': " + fItem.emptyInitState() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>boolean emptyInitState()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase5() {
        String apiTested = "boolean emptyInitState(): "
            + "TestCase: '(new FavoritesItem(null, null, null, null, null)).emptyInitState()' "
            + "ExpectedResult: 'true' "
            + "ObtainedResult: ";

        try {
            //setting necessary String objects ... start
            String name = null;
            String target = null;
            String url = null;
            String title = null;
            Locale locale = null;
            //setting necessary String objects ... end

            //construc a object ... start
            FavoritesItem fItem = new FavoritesItem(name, target, url, title, locale);
            //construc a object ... end


            if(fItem.emptyInitState() ) {
                return Status.passed(apiTested + "Got 'true'");
            } else {
                return Status.failed(apiTested + "Did not get 'true': " + fItem.emptyInitState() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>boolean emptyInitState()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase6() {
        String apiTested = "boolean emptyInitState(): "
            + "TestCase: '(new FavoritesItem(\"\", \"\", \"\", \"\", locale)).emptyInitState()' "
            + "ExpectedResult: 'true' "
            + "ObtainedResult: ";

        try {
            //setting necessary String objects ... start
            String name = "";
            String target = "";
            String url = "";
            String title = "";
            Locale locale = Locale.getDefault();
            //setting necessary String objects ... end

            //construc a object ... start
            FavoritesItem fItem = new FavoritesItem(name, target, url, title, locale);
            //construc a object ... end


            if(fItem.emptyInitState() ) {
                return Status.passed(apiTested + "Got 'true'");
            } else {
                return Status.failed(apiTested + "Did not get 'true': " + fItem.emptyInitState() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
