/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... JHelpContentViewer(hs).setSynch(value) --> JHelpContentViewer(hs).setSynch(true)
 * testCase2 ... JHelpContentViewer(hs).setSynch(value) --> JHelpContentViewer(hs).setSynch(false)
 */

package javasoft.sqe.tests.api.javax.help.JHelpContentViewer;

import java.io.PrintWriter;

import java.net.URL;

import javax.help.HelpSet;
import javax.help.JHelpContentViewer;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.JHelpContentViewer ... setSynch(...)
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class SetSynchTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public SetSynchTest() {
    }

    public static void main(String argv[]) {
        SetSynchTest test = new SetSynchTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Method test: <code>setSynch(boolean value)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>value</code> <code>true</code>
     */
    public Status testCase1() {
        String apiTested = "setSynch(boolean value): "
            + "TestCase: '(new JHelpContentViewer(hs)).setSynch(true)' "
            + "ExpectedResult: Set 'true' "
            + "ObtainedResult: ";

        try {
            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsurl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsurl);
            //creating HelpSet object ... end

            //constructing JHelpContentViewer with given value ... start
            JHelpContentViewer viewer = new JHelpContentViewer(hs);
            //constructing JHelpContentViewer with given value ... end

            //setting given patameter to JHelpContentViewer object ... start
            viewer.setSynch(true);
            //setting given patameter to JHelpContentViewer object ... end

            if(viewer.getSynch() == true) {
                return Status.passed(apiTested + "Set 'true'");
            } else {
                return Status.failed(apiTested + "Did not set 'true': " + viewer.getSynch() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>setSynch(boolean value)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>value</code> <code>false</code>
     */
    public Status testCase2() {
        String apiTested = "setSynch(boolean value): "
            + "TestCase: '(new JHelpContentViewer(hs)).setSynch(false)' "
            + "ExpectedResult: Set 'false' "
            + "ObtainedResult: ";

        try {
            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsurl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsurl);
            //creating HelpSet object ... end

            //constructing JHelpContentViewer with given value ... start
            JHelpContentViewer viewer = new JHelpContentViewer(hs);
            //constructing JHelpContentViewer with given value ... end

            //setting given patameter to JHelpContentViewer object ... start
            viewer.setSynch(false);
            //setting given patameter to JHelpContentViewer object ... end

            if(viewer.getSynch() == false) {
                return Status.passed(apiTested + "Set 'false'");
            } else {
                return Status.failed(apiTested + "Did not set 'false': " + viewer.getSynch() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
