/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... JHelpNavigator(view).getAccessibleContext() --> JHelpNavigator(view).getAccessibleContext()
 *
 * testCase2 ... JHelpNavigator(view, model).getAccessibleContext() --> JHelpNavigator(view, model).getAccessibleContext()
 */

package javasoft.sqe.tests.api.javax.help.JHelpNavigator;

import java.io.PrintWriter;

import java.net.URL;

import java.util.Locale;
import java.util.Hashtable;

import javax.help.HelpSet;
import javax.help.NavigatorView;
import javax.help.JHelpNavigator;
import javax.help.DefaultHelpModel;

import javax.swing.UIDefaults;
import javax.swing.UIManager;

import javax.accessibility.AccessibleContext;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.JHelpNavigator ... getAccessibleContext()
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class GetAccessibleContextTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public GetAccessibleContextTest() {
    }

    public static void main(String argv[]) {
        GetAccessibleContextTest test = new GetAccessibleContextTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Method test: <code>javax.accessibility.AccessibleContext getAccessibleContext()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase1() {
        String apiTested = "javax.accessibility.AccessibleContext getAccessibleContext(): "
            + "TestCase: '(new JHelpNavigator(view)).getAccessibleContext()' "
            + "ExpectedResult: 'javax.accessibility.AccessibleContext' "
            + "ObtainedResult: ";

        try {
            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsurl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsurl);
            //creating HelpSet object ... end

            // //cretaing JHelpNavigator object ... start
            Hashtable hashtab = new Hashtable();
            hashtab.put("data", "HolidayTOC.xml");

            NavigatorView view = NavigatorView.create(hs, "TOC", "Holidays", Locale.getDefault(), "javax.help.TOCView", hashtab);

            //initializing UI objects ... start
            UIDefaults table        = UIManager.getLookAndFeelDefaults();
            Object[] uiDefaults     = {"HelpNavigatorUI", "com.sun.help.jck.harness.TestNavigatorUI"};
            table.putDefaults(uiDefaults);
            //initializing UI objects ... end

            JHelpNavigator jhnavigator = new JHelpNavigator(view, new DefaultHelpModel(view.getHelpSet()) );
            // //cretaing JHelpNavigator object ... end


            Object accessibleContext = jhnavigator.getAccessibleContext();

            if (accessibleContext != null) { //returned value is not 'null'
                if (accessibleContext instanceof AccessibleContext) { //returned object is instance of AccessibleContext
                    return Status.passed(apiTested + "Got 'javax.accessibility.AccessibleContext'");
                } else { //returned object is instance of AccessibleContext
                    return Status.failed(apiTested + "Did not construct AccessibleContext object");
                }
            } else { //returned value is 'null'
                return Status.failed(apiTested + "Did not get 'javax.accessibility.AccessibleContext': " + jhnavigator.getAccessibleContext() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>javax.accessibility.AccessibleContext getAccessibleContext()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase2() {
        String apiTested = "javax.accessibility.AccessibleContext getAccessibleContext(): "
            + "TestCase: '(new JHelpNavigator(view, model)).getAccessibleContext()' "
            + "ExpectedResult: 'javax.accessibility.AccessibleContext' "
            + "ObtainedResult: ";

        try {
            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsurl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsurl);
            //creating HelpSet object ... end

            // //cretaing JHelpNavigator object ... start
            Hashtable hashtab = new Hashtable();
            hashtab.put("data", "HolidayTOC.xml");

            NavigatorView view = NavigatorView.create(hs, "TOC", "Holidays", Locale.getDefault(), "javax.help.TOCView", hashtab);

            //initializing UI objects ... start
            UIDefaults table        = UIManager.getLookAndFeelDefaults();
            Object[] uiDefaults     = {"HelpNavigatorUI", "com.sun.help.jck.harness.TestNavigatorUI"};
            table.putDefaults(uiDefaults);
            //initializing UI objects ... end

            JHelpNavigator jhnavigator = new JHelpNavigator(view, new DefaultHelpModel(view.getHelpSet()) );
            // //cretaing JHelpNavigator object ... end


            Object accessibleContext = jhnavigator.getAccessibleContext();

            if (accessibleContext != null) { //returned value is not 'null'
                if (accessibleContext instanceof AccessibleContext) { //returned object is instance of AccessibleContext
                    return Status.passed(apiTested + "Got 'javax.accessibility.AccessibleContext'");
                } else { //returned object is instance of AccessibleContext
                    return Status.failed(apiTested + "Did not construct AccessibleContext object");
                }
            } else { //returned value is 'null'
                return Status.failed(apiTested + "Did not get 'javax.accessibility.AccessibleContext': " + jhnavigator.getAccessibleContext() );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
