/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... MergeHelpUtilities.getLocale(node) --> MergeHelpUtilities.getLocale(node)
 * testCase2 ... MergeHelpUtilities.getLocale(node) --> MergeHelpUtilities.getLocale(null)
 */

package javasoft.sqe.tests.api.javax.help.MergeHelpUtilities;

import java.io.PrintWriter;

import java.net.URL;

import java.util.Locale;

import javax.help.HelpSet;
import javax.help.TOCView;
import javax.help.MergeHelpUtilities;

import javax.swing.tree.DefaultMutableTreeNode;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.MergeHelpUtilities ... getLocale(...)
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class GetLocaleTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public GetLocaleTest() {
    }

    public static void main(String argv[]) {
        GetLocaleTest test = new GetLocaleTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Method test: <code>java.util.Locale getLocale(javax.swing.tree.DefaultMutableTreeNode node)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>node</code> valid value
     */
    public Status testCase1() {
        String apiTested = "java.util.Locale getLocale(javax.swing.tree.DefaultMutableTreeNode node): "
            + "TestCase: 'MergeHelpUtilities.getLocale(node)' "
            + "ExpectedResult: 'locale' "
            + "ObtainedResult: ";

        try {
            //create a HelpSet object ... start
            HelpSet hs = new HelpSet(this.getClass().getClassLoader(), new URL("file", null, HSLOC + "/newmerge/vertebrates/Vertebrates.hs") );
            //create a HelpSet object ... end

            //get TOCView object form the HelpSet object ... start
            TOCView tocview = (TOCView)hs.getNavigatorView("TOC");
            //get TOCView object form the HelpSet object ... end

            //get root node from the TOC ... start
            DefaultMutableTreeNode node = tocview.getDataAsTree();
            //get root node from the TOC ... end

            //get name of the first child of the root node ... start
            Locale locale = MergeHelpUtilities.getLocale((DefaultMutableTreeNode)node.getFirstChild() );
            //get name of the first child of the root node ... end


            if(locale.equals(Locale.getDefault()) ) {
                return Status.passed(apiTested + "Got 'locale'");
            } else {
                return Status.failed(apiTested + "Did not get 'locale': " + MergeHelpUtilities.getLocale((DefaultMutableTreeNode)node.getFirstChild()) );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>java.util.Locale getLocale(javax.swing.tree.DefaultMutableTreeNode node)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>node</code> <code>null</code> value
     */
    public Status testCase2() {
        String apiTested = "java.util.Locale getLocale(javax.swing.tree.DefaultMutableTreeNode node): "
            + "TestCase: 'MergeHelpUtilities.getLocale(null)' "
            + "ExpectedResult: NullPointerException "
            + "ObtainedResult: ";

        try {
            //get name of the first child of the root node ... start
            Locale locale = MergeHelpUtilities.getLocale(null);
            //get name of the first child of the root node ... end


	    return Status.failed(apiTested + "Did not throw NullPointerException: " + MergeHelpUtilities.getLocale(null) );
	    
	} catch (NullPointerException npe) {
                return Status.passed(apiTested + "Threw NullPointerException");
        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
