/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... MergeHelpUtilities.sortNode(node, locale) --> MergeHelpUtilities.sortNode(node, null)
 * testCase2 ... MergeHelpUtilities.sortNode(node, locale) --> MergeHelpUtilities.sortNode(null, locale)
 */

package javasoft.sqe.tests.api.javax.help.MergeHelpUtilities;

import java.io.PrintWriter;

import java.net.URL;

import java.util.Locale;

import javax.help.HelpSet;
import javax.help.TOCView;
import javax.help.MergeHelpUtilities;

import javax.swing.tree.DefaultMutableTreeNode;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.MergeHelpUtilities ... sortNode(...)
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class SortNodeTest0 extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public SortNodeTest0() {
    }

    public static void main(String argv[]) {
        SortNodeTest0 test = new SortNodeTest0();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Method test: <code>javax.swing.tree.DefaultMutableTreeNode sortNode(javax.swing.tree.DefaultMutableTreeNode node, java.util.Locale locale)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>node</code>   valid value
     * @param <code>locale</code> <code>null</code> value
     */
    public Status testCase1() {
        String apiTested = "void sortNode(javax.swing.tree.DefaultMutableTreeNode node, java.util.Locale locale): "
            + "TestCase: 'MergeHelpUtilities.sortNode(node, null)' "
            + "ExpectedResult: 'node' "
            + "ObtainedResult: ";

        try {
            //create a HelpSet object ... start
            HelpSet hs = new HelpSet(this.getClass().getClassLoader(), new URL("file", null, HSLOC + "/newmerge/vertebrates/Vertebrates.hs") );
            //create a HelpSet object ... end

            //get TOCView object form the HelpSet object ... start
            TOCView tocview = (TOCView)hs.getNavigatorView("TOC");
            //get TOCView object form the HelpSet object ... end

            //get root node from the TOC ... start
            DefaultMutableTreeNode node = tocview.getDataAsTree();
            //get root node from the TOC ... end

            //sortNode node ... start
            Object nodetmp = MergeHelpUtilities.sortNode(node, null);
            //sortNode node ... end


            if(nodetmp instanceof DefaultMutableTreeNode) {
                return Status.passed(apiTested + "Got 'node'");
            } else {
                return Status.failed(apiTested + "Did not get 'node': " + MergeHelpUtilities.sortNode(node, null) );
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>javax.swing.tree.DefaultMutableTreeNode sortNode(javax.swing.tree.DefaultMutableTreeNode node, java.util.Locale locale)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>node</code>   <code>null</code> value
     * @param <code>locale</code> valid value
     */
    public Status testCase2() {
        String apiTested = "void sortNode(javax.swing.tree.DefaultMutableTreeNode node, java.util.Locale locale): "
            + "TestCase: 'MergeHelpUtilities.sortNode(null, locale)' "
            + "ExpectedResult: 'java.lang.NullPointerException' "
            + "ObtainedResult: ";

        try {
            //sortNode node ... start
            Object nodetmp = MergeHelpUtilities.sortNode(null, Locale.getDefault() );
            //sortNode node ... end


            return Status.failed(apiTested + "Did not get 'java.lang.NullPointerException'");
        } catch (NullPointerException exc) {
            return Status.passed(apiTested + "Got 'java.lang.NullPointerException'");
        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
