
/*
* 
* 
* @(#)SearchTOCItemTest.java	1.3 01/08/06 Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
* 
* This software is the confidential and proprietary information of Sun
* Microsystems, Inc. ("Confidential Information").  You shall not
* disclose such Confidential Information and shall use it only in
* accordance with the terms of the license agreement you entered into
* with Sun.
* 
* SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
* SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
* IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
* PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
* SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
* THIS SOFTWARE OR ITS DERIVATIVES.
* 
* CopyrightVersion 1.0
*/
package javasoft.sqe.tests.api.javax.help.SearchTOCItem;

import javax.help.search.SearchItem;
import javax.help.SearchTOCItem;
import javax.help.HelpSet;
import javax.help.Map;
import java.util.Hashtable;
import java.util.Locale;
import java.util.Vector;
import java.net.URL;
import java.io.PrintWriter;
import javasoft.sqe.javatest.Status;
import javasoft.sqe.javatest.lib.MultiTest;

/**
 * Tests for javax.help.search.SearchTOCItem;
 
 * @author Ben John.
 */

public class SearchTOCItemTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");
    
    public SearchTOCItemTest() { //constructor
        
    }
    
    public static void main(String argv[]) {
        SearchTOCItemTest test = new SearchTOCItemTest();
        Status s = test.run(argv, new PrintWriter(System.out), 
                   new PrintWriter(System.err));
        s.exit();
    }
    
    public Status testCase1() {
        String apiTested = "Method \" SearchTOCItem(SearchItem item)  \" ";
        try {
            URL url = new URL("file", null, HSLOC + "/holidays/hol/hol.html");
            Vector myv = new Vector();
            myv.addElement("One");
            myv.addElement("Two");
            SearchItem si = new SearchItem(url, "TITLE", 
                            Locale.getDefault().toString(), "hol.html", 3, 
                            1, 10, myv);
            SearchTOCItem sTOCItem = new SearchTOCItem(si);
            if(sTOCItem instanceof SearchTOCItem) {
                return Status.passed(apiTested + "Okay");
            }
            else {
                return Status.failed(apiTested + "Did not Construct valid object");
            }
        }
        catch(Exception ee) {
            return Status.failed(apiTested + "Exception raised: " + ee);
        }
    }
    
    public Status testCase2() {
        String apiTested = "Method \" SearchTOCItem(SearchItem item)  \" ";
        try {
            SearchItem si = null;
            SearchTOCItem sTOCItem = new SearchTOCItem(si);
            if(sTOCItem instanceof SearchTOCItem) {
                return Status.failed(apiTested + "Failed for null parameter");
            }
            else {
                return Status.failed(apiTested + "Did not Construct valid object");
            }
        }
        catch(Exception ee) {
            if(ee instanceof NullPointerException) {
                return Status.passed(apiTested + "Exception raised for " 
                + "null parameter " + ee);
            }
            else {
                return Status.failed(apiTested + "Exception raised for " 
                + "null parameter " + ee);
            }
        }
    }
    
    public Status testCase3() {
        String apiTested = "Method: SearchTOCItem(Map.ID id, Map.ID imageID," 
        + "HelpSet hs, java.util.Locale locale)";
        try {
            ClassLoader loader = this.getClass().getClassLoader();
            URL url = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs = new HelpSet(loader, url);
            Map.ID mid = Map.ID.create("hol_intro", hs);
            Map.ID mid2 = Map.ID.create("halloween", hs);
            SearchTOCItem sTOCItem = new SearchTOCItem(mid, mid2, hs, 
                                     Locale.getDefault());
            if(sTOCItem instanceof SearchTOCItem) {
                return Status.passed(apiTested + "Okay");
            }
            else {
                return Status.failed(apiTested + "Did not Construct valid object");
            }
        }
        catch(Exception ee) {
            ee.printStackTrace();
            return Status.failed(apiTested + "Exception raised.  " + ee);
        }
    }
    
    public Status testCase4() {
        String apiTested = "Method: SearchTOCItem(Map.ID id, Map.ID imageID," 
                           + "HelpSet hs, java.util.Locale locale)";
        try {
            ClassLoader loader = this.getClass().getClassLoader();
            URL url = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs = new HelpSet(loader, url);
            Map.ID mid = null;
            Map.ID mid2 = Map.ID.create("halloween", hs);
            SearchTOCItem sTOCItem = new SearchTOCItem(mid, mid2, hs, 
                                     Locale.getDefault());
            if(sTOCItem instanceof SearchTOCItem) {
                return Status.passed(apiTested + "Okay for null id.");
            }
            else {
                return Status.failed(apiTested + "Did not Construct valid " 
                + "object for null id.");
            }
        }
        catch(Exception ee) {
            ee.printStackTrace();
            return Status.failed(apiTested + "Exception raised for null id" + ee);
        }
    }
    
    public Status testCase5() {
        String apiTested = "Method \" SearchTOCItem(Map.ID id, Map.ID imageID,"
                           + " HelpSet hs, java.util.Locale locale)  \" ";
        try {
            ClassLoader loader = this.getClass().getClassLoader();
            URL url = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs = new HelpSet(loader, url);
            Map.ID mid = null;
            Map.ID mid2 = Map.ID.create("halloween", hs);
            SearchTOCItem sTOCItem = new SearchTOCItem(mid2, null, hs, 
                                     Locale.getDefault());
            if(sTOCItem instanceof SearchTOCItem) {
                return Status.passed(apiTested + "Okay for null imageID.");
            }
            else {
                return Status.failed(apiTested 
                + "Did not Construct valid object for null imageID.");
            }
        }
        catch(Exception ee) {
            ee.printStackTrace();
            return Status.failed(apiTested + "Exception raised for null imageID" 
            + ee);
        }
    }
    
    public Status testCase6() {
        String apiTested = "Method \" SearchTOCItem(Map.ID id, Map.ID imageID,"
                           + " HelpSet hs, java.util.Locale locale)  \" ";
        try {
            ClassLoader loader = this.getClass().getClassLoader();
            URL url = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs = new HelpSet(loader, url);
            Map.ID mid = Map.ID.create("hol_intro", hs);
            Map.ID mid2 = Map.ID.create("halloween", hs);
            SearchTOCItem sTOCItem = new SearchTOCItem(mid, mid2, null, 
                                     Locale.getDefault());
            if(sTOCItem instanceof SearchTOCItem) {
                return Status.passed(apiTested + "Okay for null hs.");
            }
            else {
                return Status.failed(apiTested 
                + "Did not Construct valid object for null hs.");
            }
        }
        catch(Exception ee) {
            ee.printStackTrace();
            return Status.failed(apiTested 
            + "Exception raised for null hs  " + ee);
        }
    }
    
    public Status testCase7() {
        String apiTested = "Method \" SearchTOCItem(Map.ID id, Map.ID imageID,"
                           + " HelpSet hs, java.util.Locale locale)  \" ";
        try {
            ClassLoader loader = this.getClass().getClassLoader();
            URL url = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs = new HelpSet(loader, url);
            Map.ID mid = Map.ID.create("hol_intro", hs);
            Map.ID mid2 = Map.ID.create("halloween", hs);
            SearchTOCItem sTOCItem = new SearchTOCItem(mid, mid2, hs, null);
            if(sTOCItem instanceof SearchTOCItem) {
                return Status.passed(apiTested + "Okay for null Locale.");
            }
            else {
                return Status.failed(apiTested 
                + "Did not Construct valid object for null Locale.");
            }
        }
        catch(Exception ee) {
            ee.printStackTrace();
            return Status.failed(apiTested 
            + "Exception raised for null Locale  " + ee);
        }
    }
}
