/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... HelpHistoryModelEvent(source, previous, next) --> HelpHistoryModelEvent(source, true, true)
 * testCase2 ... HelpHistoryModelEvent(source, previous, next) --> HelpHistoryModelEvent(source, true, false)
 * testCase3 ... HelpHistoryModelEvent(source, previous, next) --> HelpHistoryModelEvent(source, false, true)
 * testCase4 ... HelpHistoryModelEvent(source, previous, next) --> HelpHistoryModelEvent(source, false, false)
 * testCase5 ... HelpHistoryModelEvent(source, previous, next) --> HelpHistoryModelEvent(null, true, true)
 */

package javasoft.sqe.tests.api.javax.help.event.HelpHistoryModelEvent;

import java.io.PrintWriter;

import java.net.URL;

import javax.help.event.HelpHistoryModelEvent;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.event.HelpHistoryModelEvent ... HelpHistoryModelEvent()
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class HelpHistoryModelEventTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public HelpHistoryModelEventTest() {
    }

    public static void main(String argv[]) {
        HelpHistoryModelEventTest test = new HelpHistoryModelEventTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Constructor test: <code>HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>source</code>   valid value
     * @param <code>previous</code> <code>true</code>
     * @param <code>next</code>     <code>true</code>
     */
    public Status testCase1() {
        String apiTested = "HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next): "
            + "TestCase: Construct with: 'source == valid, previous == true, next == true' "
            + "ExpectedResult: HelpHistoryModelEvent object with given values "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //setting boolean values ... start
            boolean previous = true;
            boolean next     = true;
            //setting boolean values ... end

            //create HelpHistoryModelEvent object by tested constructor ... start
            HelpHistoryModelEvent helpHistoryModelEvent = new HelpHistoryModelEvent(source, previous, next);
            //create HelpHistoryModelEvent object by tested constructor ... end

            if(helpHistoryModelEvent instanceof HelpHistoryModelEvent) { //is instance of HelpHistoryModelEvent class
                if (source.equals(helpHistoryModelEvent.getSource()) ) { //source object is correct
                    if (helpHistoryModelEvent.isNext() ) { //next value is correct
                        if (helpHistoryModelEvent.isPrevious() ) { //previous value is correct
                            return Status.passed(apiTested + "OK");
                        } else { //previous value is correct
                            return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'previous' value: original: " + previous + " obtained: " + helpHistoryModelEvent.isPrevious() );
                        }
                    } else { //next value is not correct
                        return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'next' value: original: " + next + " obtained: " + helpHistoryModelEvent.isNext() );
                    }
                } else { //source object is not correct
                    return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'source' object: original: " + source + " obtained: " + helpHistoryModelEvent.getSource() );
                }
            } else { //is not instance of HelpHistoryModelEvent class
                return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object");
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Constructor test: <code>HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>source</code>   valid value
     * @param <code>previous</code> <code>true</code>
     * @param <code>next</code>     <code>false</code>
     */
    public Status testCase2() {
        String apiTested = "HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next): "
            + "TestCase: Construct with: 'source == valid, previous == true, next == false' "
            + "ExpectedResult: HelpHistoryModelEvent object with given values "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //setting boolean values ... start
            boolean previous = true;
            boolean next     = false;
            //setting boolean values ... end

            //create HelpHistoryModelEvent object by tested constructor ... start
            HelpHistoryModelEvent helpHistoryModelEvent = new HelpHistoryModelEvent(source, previous, next);
            //create HelpHistoryModelEvent object by tested constructor ... end

            if(helpHistoryModelEvent instanceof HelpHistoryModelEvent) { //is instance of HelpHistoryModelEvent class
                if (source.equals(helpHistoryModelEvent.getSource()) ) { //source object is correct
                    if ( !helpHistoryModelEvent.isNext() ) { //next value is correct
                        if (helpHistoryModelEvent.isPrevious() ) { //previous value is correct
                            return Status.passed(apiTested + "OK");
                        } else { //previous value is correct
                            return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'previous' value: original: " + previous + " obtained: " + helpHistoryModelEvent.isPrevious() );
                        }
                    } else { //next value is not correct
                        return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'next' value: original: " + next + " obtained: " + helpHistoryModelEvent.isNext() );
                    }
                } else { //source object is not correct
                    return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'source' object: original: " + source + " obtained: " + helpHistoryModelEvent.getSource() );
                }
            } else { //is not instance of HelpHistoryModelEvent class
                return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object");
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Constructor test: <code>HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>source</code>   valid value
     * @param <code>previous</code> <code>false</code>
     * @param <code>next</code>     <code>true</code>
     */
    public Status testCase3() {
        String apiTested = "HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next): "
            + "TestCase: Construct with: 'source == valid, previous == false, next == true' "
            + "ExpectedResult: HelpHistoryModelEvent object with given values "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //setting boolean values ... start
            boolean previous = false;
            boolean next     = true;
            //setting boolean values ... end

            //create HelpHistoryModelEvent object by tested constructor ... start
            HelpHistoryModelEvent helpHistoryModelEvent = new HelpHistoryModelEvent(source, previous, next);
            //create HelpHistoryModelEvent object by tested constructor ... end

            if(helpHistoryModelEvent instanceof HelpHistoryModelEvent) { //is instance of HelpHistoryModelEvent class
                if (source.equals(helpHistoryModelEvent.getSource()) ) { //source object is correct
                    if (helpHistoryModelEvent.isNext() ) { //next value is correct
                        if ( !helpHistoryModelEvent.isPrevious() ) { //previous value is correct
                            return Status.passed(apiTested + "OK");
                        } else { //previous value is correct
                            return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'previous' value: original: " + previous + " obtained: " + helpHistoryModelEvent.isPrevious() );
                        }
                    } else { //next value is not correct
                        return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'next' value: original: " + next + " obtained: " + helpHistoryModelEvent.isNext() );
                    }
                } else { //source object is not correct
                    return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'source' object: original: " + source + " obtained: " + helpHistoryModelEvent.getSource() );
                }
            } else { //is not instance of HelpHistoryModelEvent class
                return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object");
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Constructor test: <code>HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>source</code>   valid value
     * @param <code>previous</code> <code>false</code>
     * @param <code>next</code>     <code>false</code>
     */
    public Status testCase4() {
        String apiTested = "HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next): "
            + "TestCase: Construct with: 'source == valid, previous == false, next == false' "
            + "ExpectedResult: HelpHistoryModelEvent object with given values "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //setting boolean values ... start
            boolean previous = false;
            boolean next     = false;
            //setting boolean values ... end

            //create HelpHistoryModelEvent object by tested constructor ... start
            HelpHistoryModelEvent helpHistoryModelEvent = new HelpHistoryModelEvent(source, previous, next);
            //create HelpHistoryModelEvent object by tested constructor ... end

            if(helpHistoryModelEvent instanceof HelpHistoryModelEvent) { //is instance of HelpHistoryModelEvent class
                if (source.equals(helpHistoryModelEvent.getSource()) ) { //source object is correct
                    if ( !helpHistoryModelEvent.isNext() ) { //next value is correct
                        if ( !helpHistoryModelEvent.isPrevious() ) { //previous value is correct
                            return Status.passed(apiTested + "OK");
                        } else { //previous value is correct
                            return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'previous' value: original: " + previous + " obtained: " + helpHistoryModelEvent.isPrevious() );
                        }
                    } else { //next value is not correct
                        return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'next' value: original: " + next + " obtained: " + helpHistoryModelEvent.isNext() );
                    }
                } else { //source object is not correct
                    return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object with correct 'source' object: original: " + source + " obtained: " + helpHistoryModelEvent.getSource() );
                }
            } else { //is not instance of HelpHistoryModelEvent class
                return Status.failed(apiTested + "Did not construct HelpHistoryModelEvent object");
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Constructor test: <code>HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next)</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     *
     * @param <code>source</code>   <code>null</code> value
     * @param <code>previous</code> <code>true</code>
     * @param <code>next</code>     <code>true</code>
     */
    public Status testCase5() {
        String apiTested = "HelpHistoryModelEvent(java.lang.Object source, boolean previous, boolean next): "
            + "TestCase: Construct with: 'source == null, previous == true, next == true' "
            + "ExpectedResult: 'java.lang.IllegalArgumentException' "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = null;
            //creating source Object instance ... end

            //setting boolean values ... start
            boolean previous = true;
            boolean next     = true;
            //setting boolean values ... end

            //create HelpHistoryModelEvent object by tested constructor ... start
            HelpHistoryModelEvent helpHistoryModelEvent = new HelpHistoryModelEvent(source, previous, next);
            //create HelpHistoryModelEvent object by tested constructor ... end

            return Status.failed(apiTested + "Did not get 'java.lang.IllegalArgumentException'");
        } catch(IllegalArgumentException exc) {
            return Status.passed(apiTested + "Got 'java.lang.IllegalArgumentException'");
        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
