/*
 * @(#)GetIDTest.java	1.3 01/09/21
 *
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... HelpModelEvent(source, pos0, pos1).getID() --> HelpModelEvent(source, pos0, pos1).getID()
 *
 * testCase2 ... HelpModelEvent(source, id, url).getID() --> HelpModelEvent(source, id, null).getID()
 * testCase3 ... HelpModelEvent(source, id, url).getID() --> HelpModelEvent(source, null, url).getID()
 * testCase4 ... HelpModelEvent(source, id, url).getID() --> HelpModelEvent(source, id, url).getID()
 *
 * testCase5 ... HelpModelEvent(source, id, url, historyName, navigator).getID() --> HelpModelEvent(source, null, url, historyName, navigator).getID()
 * testCase6 ... HelpModelEvent(source, id, url, historyName, navigator).getID() --> HelpModelEvent(source, id, null, null, null).getID()
 * testCase7 ... HelpModelEvent(source, id, url, historyName, navigator).getID() --> HelpModelEvent(source, id, url, historyName, null).getID()
 */

package javasoft.sqe.tests.api.javax.help.event.HelpModelEvent;

import java.io.PrintWriter;

import java.net.URL;

import java.util.Locale;
import java.util.Hashtable;

import javax.help.HelpSet;
import javax.help.Map.ID;
import javax.help.NavigatorView;
import javax.help.JHelpNavigator;
import javax.help.DefaultHelpModel;

import javax.help.event.HelpModelEvent;

import javax.swing.UIDefaults;
import javax.swing.UIManager;

import javasoft.sqe.javatest.Status;
import javasoft.sqe.javatest.lib.MultiTest;

/**
 * Tests for javax.help.event.event.HelpModelEvent
 *
 * @author Meena C
 * @author Patrik Knakal
 */

public class GetIDTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public GetIDTest() {
    }

    public static void main(String argv[]) {
        GetIDTest test = new GetIDTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }

    public Status testCase1() {

        String apiTested = "getID() : "
        + "\nTestCase : Construct HelpModelEvent without specifying ID and"
        + " then call getID()"
        + "\nExpected Result :Shd return null."
        + "\nObtained Result : ";

        try {
            Object source = new Object();
            int pos0 = 0;
            int pos1 = 10;
            HelpModelEvent helpModelEvent =new HelpModelEvent(source,pos0,pos1);
            ID gotMapID = helpModelEvent.getID();
            if(gotMapID == null) {
                return Status.passed(apiTested + "Returned null ID\n");
            } else {
                return Status.failed(apiTested + "Did not return null ID\n");
            }
        } catch(Exception e) {
            return Status.failed(apiTested + "Got Exception : " + e + "\n");
        }
    }

    public Status testCase2() {

        String apiTested = "getID() : "
        + "\nTestCase : Construct HelpModelEvent with a valid ID and"
        + " then call getID()"
        + "\nExpected Result :Shd return given ID."
        + "\nObtained Result : ";

        try {
            Object source = new Object();
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl = new URL("file", null, HSLOC+"/holidays/HolidayHistory.hs");
            HelpSet hs = new HelpSet(cl, hsUrl);
            String id = "hol_intro";
            ID mapID = ID.create(id, hs);
            URL url = null;
            HelpModelEvent helpModelEvent =new HelpModelEvent(source,mapID,url);
            ID gotMapID = helpModelEvent.getID();
            if(gotMapID.equals(mapID)) {
                return Status.passed(apiTested + "Returned given ID."
                	+ "\nGiven ID : " + mapID + "\nGot Id : "
                	+ gotMapID + "\n");
            } else {
                return Status.failed(apiTested + "Did not return given ID."
                	+ "\nGiven ID : " + mapID + "\nGot Id : "
                	+ gotMapID + "\n");
            }
        } catch(Exception e) {
            return Status.failed(apiTested + "Got Exception : " + e + "\n");
        }
    }

    public Status testCase3() {

        String apiTested = "getID() : "
        + "\nTestCase : Construct HelpModelEvent with null ID and"
        + " then call getID()"
        + "\nExpected Result :Shd return null."
        + "\nObtained Result : ";

        try {
            Object source = new Object();
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl = new URL("file", null, HSLOC+"/holidays/HolidayHistory.hs");
            HelpSet hs = new HelpSet(cl, hsUrl);
            String id = "hol_intro";
            ID tempID = ID.create(id, hs);
            URL url = (hs.getCombinedMap()).getURLFromID(tempID);
            ID mapID = null;
            HelpModelEvent helpModelEvent =new HelpModelEvent(source,mapID,url);
            ID gotMapID = helpModelEvent.getID();
            if(gotMapID == mapID) {
                return Status.passed(apiTested + "Returned null ID."
                	+ "\nGiven ID : " + mapID + "\nGot Id : "
                	+ gotMapID + "\n");
            } else {
                return Status.failed(apiTested + "Did not return null ID."
                	+ "\nGiven ID : " + mapID + "\nGot Id : "
                	+ gotMapID + "\n");
            }
        } catch(Exception e) {
            return Status.failed(apiTested + "Got Exception : " + e + "\n");
        }
    }


    /**
     * Method test: <code>javax.help.Map.ID getID()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase4() {
        String apiTested = "javax.Help.Map.ID getID(): "
            + "TestCase: '(new HelpModelEvent(source, id, url)).getID()' "
            + "ExpectedResult: 'id' "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsUrl);
            //creating HelpSet object ... end

            //creating Map.ID object ... start
            String id = "hol_intro";
            ID mapID  = ID.create(id, hs);
            //creating Map.ID object ... end

            //creating temporary Map.ID object for getting URL object ... start
            ID tmpID = ID.create(id, hs);
            //creating temporary Map.ID object for getting URL object ... end

            //construct URL for HelpModelEvent construction ... start
            URL url = (hs.getCombinedMap() ).getURLFromID(tmpID);
            //construct URL for HelpModelEvent construction ... end

            //creating HelpModelEvent object form given parameters ... start
            HelpModelEvent helpModelEvent = new HelpModelEvent(source, mapID, url);
            //creating HelpModelEvent object form given parameters ... end

            if(mapID.equals(helpModelEvent.getID()) ) {
                return Status.passed(apiTested + "Got 'id'");
            } else {
                return Status.failed(apiTested + "Did not get 'id': " + helpModelEvent.getID() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>javax.help.Map.ID getID()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase5() {
        String apiTested = "javax.Help.Map.ID getID(): "
            + "TestCase: '(new HelpModelEvent(source, null, url, historyName, navigator)).getID()' "
            + "ExpectedResult: 'null' "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsUrl);
            //creating HelpSet object ... end

            //creating Map.ID object ... start
            String id = "hol_intro";
            ID mapID  = null;
            //creating Map.ID object ... end

            //creating temporary Map.ID object for getting URL object ... start
            ID tmpID  = ID.create(id, hs);
            //creating temporary Map.ID object for getting URL object ... end

            //construct URL for HelpModelEvent construction ... start
            URL url = (hs.getCombinedMap() ).getURLFromID(tmpID);
            //construct URL for HelpModelEvent construction ... end

            //seting a name for bookmark ... start
            String historyName = "holidays";
            //seting a name for bookmark ... end

            // //cretaing JHelpNavigator object ... start
            Hashtable hashtab = new Hashtable();
            hashtab.put("data", "HolidayTOC.xml");

            NavigatorView navigator = NavigatorView.create(hs, "TOC", "Holidays", Locale.getDefault(), "javax.help.TOCView", hashtab);

            //initializing UI objects ... start
            UIDefaults table        = UIManager.getLookAndFeelDefaults();
            Object[] uiDefaults     = {"HelpNavigatorUI", "com.sun.help.jck.harness.TestNavigatorUI"};
            table.putDefaults(uiDefaults);
            //initializing UI objects ... end

            JHelpNavigator jhnavigator = new JHelpNavigator(navigator, new DefaultHelpModel(navigator.getHelpSet()) );
            // //cretaing JHelpNavigator object ... end

            //creating HelpModelEvent object form given parameters ... start
            HelpModelEvent helpModelEvent = new HelpModelEvent(source, mapID, url, historyName, jhnavigator);
            //creating HelpModelEvent object form given parameters ... end

            if(mapID == helpModelEvent.getID() ) {
                return Status.passed(apiTested + "Got 'null'");
            } else {
                return Status.failed(apiTested + "Did not get 'null': " + helpModelEvent.getID() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>javax.Help.Map.ID getID()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase6() {
        String apiTested = "javax.Help.Map.ID getID(): "
            + "TestCase: '(new HelpModelEvent(source, id, null, null, null)).getID()' "
            + "ExpectedResult: 'id' "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsUrl);
            //creating HelpSet object ... end

            //creating Map.ID object ... start
            String id = "hol_intro";
            ID mapID  = ID.create(id, hs);
            //creating Map.ID object ... end

            //construct URL for HelpModelEvent construction ... start
            URL url = null;
            //construct URL for HelpModelEvent construction ... end

            //seting a name for bookmark ... start
            String historyName = null;
            //seting a name for bookmark ... end

            //cretaing JHelpNavigator object ... start
            JHelpNavigator jhnavigator = null;
            //cretaing JHelpNavigator object ... end

            //creating HelpModelEvent object form given parameters ... start
            HelpModelEvent helpModelEvent = new HelpModelEvent(source, mapID, url, historyName, jhnavigator);
            //creating HelpModelEvent object form given parameters ... end

            if(mapID.equals(helpModelEvent.getID()) ) {
                return Status.passed(apiTested + "Got 'id'");
            } else {
                return Status.failed(apiTested + "Did not get 'id': " + helpModelEvent.getID() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>javax.help.Map.ID getID()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase7() {
        String apiTested = "javax.Help.Map.ID getID(): "
            + "TestCase: '(new HelpModelEvent(source, id, url, historyName, null)).getID()' "
            + "ExpectedResult: 'id' "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsUrl);
            //creating HelpSet object ... end

            //creating Map.ID object ... start
            String id = "hol_intro";
            ID mapID  = ID.create(id, hs);
            //creating Map.ID object ... end

            //creating temporary Map.ID object for getting URL object ... start
            ID tmpID  = ID.create(id, hs);
            //creating temporary Map.ID object for getting URL object ... end

            //construct URL for HelpModelEvent construction ... start
            URL url = (hs.getCombinedMap() ).getURLFromID(tmpID);
            //construct URL for HelpModelEvent construction ... end

            //seting a name for bookmark ... start
            String historyName = "holidays";
            //seting a name for bookmark ... end

            //cretaing JHelpNavigator object ... start
            JHelpNavigator jhnavigator = null;
            //cretaing JHelpNavigator object ... end

            //creating HelpModelEvent object form given parameters ... start
            HelpModelEvent helpModelEvent = new HelpModelEvent(source, mapID, url, historyName, jhnavigator);
            //creating HelpModelEvent object form given parameters ... end

            if(mapID.equals(helpModelEvent.getID()) ) {
                return Status.passed(apiTested + "Got 'id'");
            } else {
                return Status.failed(apiTested + "Did not get 'id': " + helpModelEvent.getID() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
