/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0 
 */

/*
 * TestCases summary:
 * testCase1 ... HelpModelEvent(source, pos0, pos1).getNavigator() --> HelpModelEvent(source, pos0, pos1).getNavigator()
 *
 * testCase2 ... HelpModelEvent(source, id, url).getNavigator() --> HelpModelEvent(source, id, null).getNavigator()
 * testCase3 ... HelpModelEvent(source, id, url).getNavigator() --> HelpModelEvent(source, null, url).getNavigator()
 *
 * testCase4 ... HelpModelEvent(source, id, url, historyName, navigator).getNavigator() --> HelpModelEvent(source, null, url, historyName, navigator).getNavigator()
 * testCase5 ... HelpModelEvent(source, id, url, historyName, navigator).getNavigator() --> HelpModelEvent(source, id, null, null, null).getNavigator()
 */

package javasoft.sqe.tests.api.javax.help.event.HelpModelEvent;

import java.io.PrintWriter;

import java.net.URL;

import java.util.Locale;
import java.util.Hashtable;

import javax.help.HelpSet;
import javax.help.Map.ID;
import javax.help.NavigatorView;
import javax.help.JHelpNavigator;
import javax.help.DefaultHelpModel;

import javax.help.event.HelpModelEvent;

import javax.swing.UIDefaults;
import javax.swing.UIManager;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.event.HelpModelEvent ... getNavigator()
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class GetNavigatorTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public GetNavigatorTest() {
    }

    public static void main(String argv[]) {
        GetHistoryNameTest test = new GetHistoryNameTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Method test: <code>javax.help.JHelpNavigator getNavigator()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase1() {
        String apiTested = "javax.help.JHelpNavigator getNavigator(): "
            + "TestCase: '(new HelpModelEvent(source, pos0, pos1)).getNavigator()' "
            + "ExpectedResult: 'null' "
            + "ObtainedResult: ";

        try {
            //creating initial object ... start
            Object source = new Object();
            int pos0      = 0;
            int pos1      = 10;
            //creating initial object ... start

            //creating HelpModelEvent object form given parameters ... start
            HelpModelEvent helpModelEvent = new HelpModelEvent(source, pos0, pos1);
            //creating HelpModelEvent object form given parameters ... start

            if(helpModelEvent.getNavigator() == null) {
                return Status.passed(apiTested + "Got 'null'");
            } else {
                return Status.failed(apiTested + "Did not get 'null': " + helpModelEvent.getNavigator() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>javax.help.JHelpNavigator getNavigator()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase2() {
        String apiTested = "javax.help.JHelpNavigator getNavigator(): "
            + "TestCase: '(new HelpModelEvent(source, id, null)).getNavigator()' "
            + "ExpectedResult: 'null' "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsUrl);
            //creating HelpSet object ... end

            //creating Map.ID object ... start
            String id = "hol_intro";
            ID mapID  = ID.create(id, hs);
            //creating Map.ID object ... end

            //construct URL for HelpModelEvent construction ... start
            URL url = null;
            //construct URL for HelpModelEvent construction ... end

            //creating HelpModelEvent object form given parameters ... start
            HelpModelEvent helpModelEvent = new HelpModelEvent(source, mapID, url);
            //creating HelpModelEvent object form given parameters ... end

            if(helpModelEvent.getNavigator() == null) {
                return Status.passed(apiTested + "Got 'null'");
            } else {
                return Status.failed(apiTested + "Did not get 'null': " + helpModelEvent.getNavigator() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>javax.help.JHelpNavigator getNavigator()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase3() {
        String apiTested = "javax.help.JHelpNavigator getNavigator(): "
            + "TestCase: '(new HelpModelEvent(source, null, url)).getNavigator()' "
            + "ExpectedResult: 'null' "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsUrl);
            //creating HelpSet object ... end

            //creating Map.ID object ... start
            String id = "hol_intro";
            ID mapID  = null;
            //creating Map.ID object ... end

            //creating temporary Map.ID object for getting URL object ... start
            ID tmpID  = ID.create(id, hs);
            //creating temporary Map.ID object for getting URL object ... end

            //construct URL for HelpModelEvent construction ... start
            URL url = (hs.getCombinedMap() ).getURLFromID(tmpID);
            //construct URL for HelpModelEvent construction ... end

            //creating HelpModelEvent object form given parameters ... start
            HelpModelEvent helpModelEvent = new HelpModelEvent(source, mapID, url);
            //creating HelpModelEvent object form given parameters ... end

            if(helpModelEvent.getNavigator() == null) {
                return Status.passed(apiTested + "Got 'null'");
            } else {
                return Status.failed(apiTested + "Did not get 'null': " + helpModelEvent.getNavigator() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>javax.help.JHelpNavigator getNavigator()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase4() {
        String apiTested = "javax.help.JHelpNavigator getNavigator(): "
            + "TestCase: '(new HelpModelEvent(source, null, url, historyName, navigator)).getNavigator()' "
            + "ExpectedResult: 'historyName' "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsUrl);
            //creating HelpSet object ... end

            //creating Map.ID object ... start
            String id = "hol_intro";
            ID mapID  = null;
            //creating Map.ID object ... end

            //creating temporary Map.ID object for getting URL object ... start
            ID tmpID  = ID.create(id, hs);
            //creating temporary Map.ID object for getting URL object ... end

            //construct URL for HelpModelEvent construction ... start
            URL url = (hs.getCombinedMap() ).getURLFromID(tmpID);
            //construct URL for HelpModelEvent construction ... end

            //seting a name for bookmark ... start
            String historyName = "holidays";
            //seting a name for bookmark ... end

            // //cretaing JHelpNavigator object ... start
            Hashtable hashtab = new Hashtable();
            hashtab.put("data", "HolidayTOC.xml");

            NavigatorView navigator = NavigatorView.create(hs, "TOC", "Holidays", Locale.getDefault(), "javax.help.TOCView", hashtab);

            //initializing UI objects ... start
            UIDefaults table        = UIManager.getLookAndFeelDefaults();
            Object[] uiDefaults     = {"HelpNavigatorUI", "com.sun.help.jck.harness.TestNavigatorUI"};
            table.putDefaults(uiDefaults);
            //initializing UI objects ... end

            JHelpNavigator jhnavigator = new JHelpNavigator(navigator, new DefaultHelpModel(navigator.getHelpSet()) );
            // //cretaing JHelpNavigator object ... end

            //creating HelpModelEvent object form given parameters ... start
            HelpModelEvent helpModelEvent = new HelpModelEvent(source, mapID, url, historyName, jhnavigator);
            //creating HelpModelEvent object form given parameters ... end

            if(jhnavigator.equals(helpModelEvent.getNavigator()) ) {
                return Status.passed(apiTested + "Got 'navigator'");
            } else {
                return Status.failed(apiTested + "Did not get 'navigator': " + helpModelEvent.getNavigator() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>javax.help.JHelpNavigator getNavigator()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase5() {
        String apiTested = "javax.help.JHelpNavigator getNavigator(): "
            + "TestCase: '(new HelpModelEvent(source, id, null, null, null)).getNavigator()' "
            + "ExpectedResult: 'null' "
            + "ObtainedResult: ";

        try {
            //creating source Object instance ... start
            Object source = new Object();
            //creating source Object instance ... end

            //creating HelpSet object ... start
            ClassLoader cl = this.getClass().getClassLoader();
            URL hsUrl      = new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs");
            HelpSet hs     = new HelpSet(cl, hsUrl);
            //creating HelpSet object ... end

            //creating Map.ID object ... start
            String id = "hol_intro";
            ID mapID  = ID.create(id, hs);
            //creating Map.ID object ... end

            //construct URL for HelpModelEvent construction ... start
            URL url = null;
            //construct URL for HelpModelEvent construction ... end

            //seting a name for bookmark ... start
            String historyName = null;
            //seting a name for bookmark ... end

            //cretaing JHelpNavigator object ... start
            JHelpNavigator jhnavigator = null;
            //cretaing JHelpNavigator object ... end

            //creating HelpModelEvent object form given parameters ... start
            HelpModelEvent helpModelEvent = new HelpModelEvent(source, mapID, url, historyName, jhnavigator);
            //creating HelpModelEvent object form given parameters ... end

            if(jhnavigator == helpModelEvent.getNavigator() ) {
                return Status.passed(apiTested + "Got 'null'");
            } else {
                return Status.failed(apiTested + "Did not get 'null': " + helpModelEvent.getNavigator() );
            }

        } catch(Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }
}
