/*
 * Copyright (c) 1998-1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * CopyrightVersion 1.0
 */

/*
 * TestCases summary:
 * testCase1 ... MergingSearchEngine(engine).getEngines() --> MergingSearchEngine(engine).getEngines()
 * testCase2 ... MergingSearchEngine(engine).getEngines() --> MergingSearchEngine(engine).merge(view).getEngines()
 */

package javasoft.sqe.tests.api.javax.help.search.MergingSearchEngine;

import java.io.PrintWriter;

import java.net.URL;

import java.util.Locale;
import java.util.Hashtable;
import java.util.Enumeration;

import javax.help.HelpSet;
import javax.help.NavigatorView;

import javax.help.search.SearchEngine;
import javax.help.search.MergingSearchEngine;

import com.sun.java.help.search.DefaultSearchEngine;

import com.sun.javatest.Status;
import com.sun.javatest.lib.MultiTest;

/**
 * Tests for javax.help.search.MergingSearchEngine ... getEngines()
 *
 * @author Patrik Knakal
 *
 * @since JH2.0
 */
public class GetEnginesTest extends MultiTest {
    public static String HSLOC = System.getProperty("HS_LOC");

    public GetEnginesTest() {
    }

    public static void main(String argv[]) {
        GetEnginesTest test = new GetEnginesTest();
        Status s = test.run(argv, new PrintWriter(System.out), new PrintWriter(System.err));
        s.exit();
    }


    /**
     * Method test: <code>java.util.Enumeration getEngines()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase1() {
        String apiTested = "java.util.Enumeration getEngines(): "
            + "TestCase: '(new MergingSearchEngine(engine)).getEngines()' "
            + "ExpectedResult: 'view' "
            + "ObtainedResult: ";

        try {
            //create a SearchEngine object ... start
            Hashtable hashtable = new Hashtable();
            hashtable.put("data", "JavaHelpSearch");
            SearchEngine searchengine = new DefaultSearchEngine(new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs"), hashtable);
            //create a SearchEngine object ... end

            //create a MergingSearchEngine object ... start
            MergingSearchEngine engine = new MergingSearchEngine(searchengine);
            //create a MergingSearchEngine object ... end


            //test the number of engines ... start
            Enumeration enum = engine.getEngines();
            //test the number of engines ... end

            if (searchengine.equals((SearchEngine)enum.nextElement()) && !enum.hasMoreElements() ) {
                return Status.passed(apiTested + "Got 'view'");
            } else {
                return Status.failed(apiTested + "Did not get 'view'");
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }


    /**
     * Method test: <code>java.util.Enumeration getEngines()</code>
     *
     * @author Patrik Knakal
     *
     * @since JH2.0
     */
    public Status testCase2() {
        String apiTested = "java.util.Enumeration getEngines(): "
            + "TestCase: '(new MergingSearchEngine(engine)).merge(view).getEngines()' "
            + "ExpectedResult: Add 'view' "
            + "ObtainedResult: ";

        try {
            //create a SearchEngine object ... start
            Hashtable hashtable = new Hashtable();
            hashtable.put("data", "JavaHelpSearch");
            SearchEngine searchengine = new DefaultSearchEngine(new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs"), hashtable);
            //create a SearchEngine object ... end

            //create a MergingSearchEngine object ... start
            MergingSearchEngine engine = new MergingSearchEngine(searchengine);
            //create a MergingSearchEngine object ... end

            //create a NavigatorView object ... start
            hashtable = new Hashtable();
            hashtable.put("data", "JavaHelpSearch");
            NavigatorView mergeview = NavigatorView.create(new HelpSet(this.getClass().getClassLoader(), new URL("file", null, HSLOC + "/holidays/HolidayHistory.hs")), "TOC2", "Jewish Holidays", Locale.getDefault(), "javax.help.TOCView", hashtable);
            //create a NavigatorView object ... end

            //merge new engine ... start
            engine.merge(mergeview);
            //merge new engine ... end

            //test the number of engines ... start
            Enumeration enum = engine.getEngines();
            //test the number of engines ... end


            if (((SearchEngine)enum.nextElement()).equals(searchengine) && (enum.nextElement() instanceof com.sun.java.help.search.DefaultSearchEngine) && !enum.hasMoreElements() ) {
                return Status.passed(apiTested + "Added 'view'");
            } else {
                return Status.failed(apiTested + "Did not add 'view'");
            }

        } catch (Exception exc) {
            exc.printStackTrace();
            return Status.failed(apiTested + "Got Exception: " + exc);
        }
    }

}
